@@ -35,19 +35,18 @@ class IvyBloomAPIClient:
     
     def _ensure_authenticated(self) -> None:
         """Ensure user is authenticated before making requests"""
-        api_key = self.auth_manager.get_api_key()
-        if not api_key:
+        # Accept any valid auth method: JWT/OAuth/API key
+        if not self.auth_manager.is_authenticated():
             raise Exception(
-                "Authentication required. Please run 'ivybloom auth link' to link your CLI to your account.\n"
-                "Alternatively, you can run 'ivybloom auth login --api-key' with a manual API key."
+                "Authentication required. Please run 'ivybloom auth login' (browser/device/link) or provide an API key."
             )
     
     def _get_default_headers(self) -> Dict[str, str]:
         """Get default headers for requests"""
-        # Build default headers including auth; prefer JWT/OAuth, fallback to API key
+        # Build default headers including auth; prefer API key for stability, then JWT/OAuth
         headers = {
             "Content-Type": "application/json",
-            "User-Agent": "ivybloom-cli/0.4.13",
+            "User-Agent": "ivybloom-cli/0.4.28",
             "Accept": "application/json"
         }
         # Add Authorization header via AuthManager (JWT/OAuth/API key)
@@ -113,7 +112,8 @@ class IvyBloomAPIClient:
                 raise Exception("❌ CLI not linked to your account. Run 'ivybloom auth link' to link this CLI installation.")
             
             # Try refreshing tokens and retrying once
-            print_info("Access token may be expired, attempting refresh...")
+            # Send human-readable notice to stderr so stdout remains machine-parseable
+            print("Access token may be expired, attempting refresh...", file=sys.stderr)
             self._refresh_headers()
             
             # Retry the request with refreshed headers
@@ -163,7 +163,8 @@ class IvyBloomAPIClient:
                 raise Exception("Authentication required. Run 'ivybloom auth link' to link this CLI and retry.")
             
             # Try refreshing tokens and retrying once
-            print_info("Access token may be expired, attempting refresh...")
+            # Send human-readable notice to stderr so stdout remains machine-parseable
+            print("Access token may be expired, attempting refresh...", file=sys.stderr)
             self._refresh_headers()
             
             # Retry the request with refreshed headers
