@@ -10,6 +10,7 @@ from rich.table import Table
 from ..utils.auth import AuthManager
 from ..utils.config import Config
 from ..client.api_client import IvyBloomAPIClient
+from ..utils.printing import emit_json
 from ..utils.colors import get_console, print_success, print_error, print_warning, print_info
 
 console = get_console()
@@ -93,7 +94,7 @@ def info(ctx, format):
             account_data = client.get_account_info()
         
         if format == 'json':
-            console.print(json.dumps(account_data, indent=2))
+            emit_json(account_data)
         else:
             console.print(f"[bold cyan]👤 Account Information[/bold cyan]")
             console.print(f"   Email: {account_data.get('email', 'Unknown')}")
@@ -189,7 +190,7 @@ def usage(ctx, format, tool, period):
             usage_data = filtered_data
         
         if format == 'json':
-            console.print(json.dumps(usage_data, indent=2))
+            emit_json(usage_data)
         else:
             console.print("[bold cyan]📊 Usage Statistics[/bold cyan]")
             
