@@ -16,6 +16,7 @@ from ..client.api_client import IvyBloomAPIClient
 from ..utils.config import Config
 from ..utils.auth import AuthManager
 from ..utils.colors import get_console, print_success, print_error, print_warning, print_info
+from ..utils.printing import emit_json
 
 console = get_console()
 
@@ -231,7 +232,7 @@ def list(ctx, project_id: str, file_type: str, tags: str, limit: int, format: st
                 console.print(table)
             
             elif format == 'json':
-                console.print(json.dumps(mock_files, indent=2))
+                emit_json(mock_files)
             
             else:  # yaml
                 import yaml
