@@ -81,8 +81,8 @@ def list(ctx, format, interactive):
     auth_manager = AuthManager(config)
     
     if not auth_manager.is_authenticated():
-        console.print("[red]❌ Not authenticated. Run 'ivybloom auth login' first.[/red]")
-        return
+        # Ensure non-zero exit and stderr output so JSON consumers aren't polluted
+        raise click.ClickException("Not authenticated. Run 'ivybloom auth login' first.")
     
     try:
         with IvyBloomAPIClient(config, auth_manager) as client:
@@ -167,7 +167,8 @@ def list(ctx, format, interactive):
                             _execute_project_action(ctx, selected_project_id, action, selected_project_data)
     
     except Exception as e:
-        console.print(f"[red]❌ Error listing projects: {e}[/red]")
+        # Surface as CLI error (stderr, non-zero)
+        raise click.ClickException(f"Error listing projects: {e}")
 
 @projects.command()
 @click.argument('project_id')
@@ -200,8 +201,7 @@ def info(ctx, project_id, format):
     auth_manager = AuthManager(config)
     
     if not auth_manager.is_authenticated():
-        console.print("[red]❌ Not authenticated. Run 'ivybloom auth login' first.[/red]")
-        return
+        raise click.ClickException("Not authenticated. Run 'ivybloom auth login' first.")
     
     try:
         with IvyBloomAPIClient(config, auth_manager) as client:
@@ -222,7 +222,7 @@ def info(ctx, project_id, format):
             console.print(f"   Last Activity: {project_data.get('last_activity', 'Never')}")
     
     except Exception as e:
-        console.print(f"[red]❌ Error getting project info: {e}[/red]")
+        raise click.ClickException(f"Error getting project info: {e}")
 
 @projects.command()
 @click.argument('project_id')
@@ -257,8 +257,7 @@ def jobs(ctx, project_id, format):
     auth_manager = AuthManager(config)
     
     if not auth_manager.is_authenticated():
-        console.print("[red]❌ Not authenticated. Run 'ivybloom auth login' first.[/red]")
-        return
+        raise click.ClickException("Not authenticated. Run 'ivybloom auth login' first.")
     
     try:
         with IvyBloomAPIClient(config, auth_manager) as client:
@@ -305,7 +304,7 @@ def jobs(ctx, project_id, format):
             console.print(table)
     
     except Exception as e:
-        console.print(f"[red]❌ Error listing project jobs: {e}[/red]")
+        raise click.ClickException(f"Error listing project jobs: {e}")
 
 def _execute_project_action(ctx, project_id: str, action: str, project_data: Dict[str, Any]):
     """Execute the selected action on a project"""
