@@ -4,6 +4,7 @@ from typing import Optional, Dict, Any, List, Tuple
 import webbrowser
 import json
 import sys
+import os
 
 try:
     from textual.app import App, ComposeResult
@@ -28,6 +29,7 @@ from .screens import CommandPalette, PromptScreen, FiltersScreen, SplashScreen,
 from .views import JobsView, DetailsView
 from .history import HistoryManager
 from .debug_logger import DebugLogger
+from .commands import auth_cmds, config_cmds, data_cmds, batch_cmds, workflows_cmds, tools_cmds, projects_cmds, account_cmds, jobs_cmds, artifacts_cmds
 
 
 class IvyBloomTUI(App):
@@ -69,6 +71,7 @@ class IvyBloomTUI(App):
         ("ctrl+k", "open_palette", "Commands"),
         ("f", "focus_filter", "Filter"),
         ("o", "open_external", "Open Artifact"),
+        ("p", "pick_project", "Pick Project"),
         ("?", "toggle_help", "Help"),
         ("tab", "focus_next", "Next"),
         ("shift+tab", "focus_previous", "Prev"),
@@ -79,7 +82,8 @@ class IvyBloomTUI(App):
         super().__init__()
         self.config = config
         self.auth_manager = auth_manager
-        self.initial_project_id = initial_project_id
+        # Prefer provided project id, else fallback to last used project from config
+        self.initial_project_id = initial_project_id or self.config.get("last_project_id") or None
         self.show_header = show_header
         self.show_footer = show_footer
 
@@ -108,9 +112,10 @@ class IvyBloomTUI(App):
         self._help_prev_renderable = None
 
         # Services
-        # Route debug to a file by default to avoid overlay; respect --debug flag
-        log_file = str(self.config.config_dir / "tui_debug.log") if bool(self.config.get("debug", False)) else None
-        self._debug_logger = DebugLogger(enabled=bool(self.config.get("debug", False)), prefix="TUI", log_path=log_file)
+        # Route debug to a file by default to avoid overlay; respect --debug flag or env toggle
+        debug_enabled = bool(self.config.get("debug", False)) or os.environ.get("IVYBLOOM_TUI_DEBUG") == "1"
+        log_file = str(self.config.config_dir / "tui_debug.log") if debug_enabled else None
+        self._debug_logger = DebugLogger(enabled=debug_enabled, prefix="TUI", log_path=log_file)
         self._runner = CLIRunner(self.config, logger=self._debug_logger)
         self._artifacts = ArtifactsService(self._runner, logger=self._debug_logger)
         self._structure = StructureService()
@@ -370,13 +375,16 @@ class IvyBloomTUI(App):
 
     # ------------------ Command Palette ------------------
     def action_open_palette(self) -> None:
-        if not self._require_ready():
-            return
+        # Allow opening the palette even before readiness so users can pick a project
         commands = [
             ("list_tools", "Tools: List", "Show tools (choose format/verbosity)"),
             ("tools_info", "Tools: Info", "Show detailed info for a tool (choose format)"),
             ("tools_schema", "Tools: Schema", "Show parameter schema for a tool (choose format)"),
             ("tools_completions", "Tools: Completions", "Show enum choices for a tool (choose format)"),
+            ("auth_status", "Auth: Status", "Show authentication status"),
+            ("auth_whoami", "Auth: Whoami", "Show current user info"),
+            ("auth_logout", "Auth: Logout", "Logout and clear credentials"),
+            ("auth_link", "Auth: Link", "Link this CLI to your account"),
             ("jobs_list", "Jobs: List", "List jobs with optional filters"),
             ("jobs_status", "Jobs: Status", "Show job status (optionally follow)"),
             ("jobs_results", "Jobs: Results", "Fetch job results (JSON)"),
@@ -387,8 +395,25 @@ class IvyBloomTUI(App):
             ("projects_jobs", "Projects: Jobs", "List jobs for a project"),
             ("account_info", "Account: Info", "Show account info"),
             ("account_usage", "Account: Usage", "Show usage (choose period/tool)"),
+            ("config_show", "Config: Show", "Show runtime configuration"),
+            ("config_list", "Config: List", "List all configuration values"),
+            ("config_get", "Config: Get", "Get a configuration value"),
+            ("config_set", "Config: Set", "Set a configuration value"),
+            ("config_reset", "Config: Reset", "Reset configuration to defaults"),
+            ("config_path", "Config: Path", "Show configuration file path"),
+            ("config_unset", "Config: Unset", "Remove a configuration key"),
+            ("config_export", "Config: Export", "Export configuration to file"),
+            ("config_import", "Config: Import", "Import configuration from file"),
+            ("data_upload", "Data: Upload", "Upload a file to storage"),
+            ("data_list", "Data: List", "List stored files"),
+            ("data_download", "Data: Download", "Download a file by ID"),
+            ("data_delete", "Data: Delete", "Delete a file by ID"),
+            ("data_sync", "Data: Sync", "Sync a local directory"),
             ("run_tool", "Run: Tool", "Run a tool with key=value params"),
             ("workflows_run", "Workflows: Run", "Run a workflow file"),
+            ("workflows_validate", "Workflows: Validate", "Validate a workflow file"),
+            ("workflows_create", "Workflows: Create", "Create a workflow template"),
+            ("workflows_list", "Workflows: List", "List workflow templates"),
             ("run_custom", "Run: CLI (Custom)", "Run arbitrary ivybloom args; supports unknown flags"),
             ("run_history", "Run: History", "View and re-run recent custom commands"),
             ("run_history_clear", "Run: History (Clear)", "Clear custom run history"),
@@ -417,7 +442,7 @@ class IvyBloomTUI(App):
             def _after_fmt(fmt: Optional[str]):
                 def _after_verbose(verbose: Optional[str]):
                     def _after_schemas(schemas: Optional[str]):
-                        self.call_later(lambda: self._cmd_tools_list(fmt or "table", (verbose or "no").lower() in {"yes","y","true"}, (schemas or "no").lower() in {"yes","y","true"}))
+                        self.call_later(lambda: self._update_details_with_text(tools_cmds.list_tools(self._runner, fmt or "table", (verbose or "no").lower() in {"yes","y","true"}, (schemas or "no").lower() in {"yes","y","true"})))
                     self.push_screen(PromptScreen("Embed schemas? (yes/no)", placeholder="no"), _after_schemas)
                 self.push_screen(PromptScreen("Verbose? (yes/no)", placeholder="no"), _after_verbose)
             self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), _after_fmt)
@@ -425,19 +450,19 @@ class IvyBloomTUI(App):
             def _after_tool(tool: Optional[str]):
                 if not tool:
                     return
-                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._cmd_tools_info(tool, fmt or "table"))
+                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._update_details_with_text(tools_cmds.info(self._runner, tool, fmt or "table")))
             self.push_screen(PromptScreen("Tool name (e.g., esmfold)"), _after_tool)
         elif result == "tools_schema":
             def _after_tool_schema(tool: Optional[str]):
                 if not tool:
                     return
-                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._cmd_tools_schema(tool, fmt or "table"))
+                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._update_details_with_text(tools_cmds.schema(self._runner, tool, fmt or "table")))
             self.push_screen(PromptScreen("Tool name for schema"), _after_tool_schema)
         elif result == "tools_completions":
             def _after_tool_comp(tool: Optional[str]):
                 if not tool:
                     return
-                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._cmd_tools_completions(tool, fmt or "table"))
+                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._update_details_with_text(tools_cmds.completions(self._runner, tool, fmt or "table")))
             self.push_screen(PromptScreen("Tool name for completions"), _after_tool_comp)
         elif result == "jobs_list":
             self.push_screen(FiltersScreen(), lambda filters: self._cmd_jobs_list_with_filters(filters))
@@ -449,23 +474,86 @@ class IvyBloomTUI(App):
                 self.push_screen(PromptScreen("Extra flags (e.g., --follow --logs)", placeholder="optional"), lambda flags: self._cmd_jobs_status(job_id, flags))
             self.push_screen(PromptScreen("Job ID (then choose flags)"), _after_job_id)
         elif result == "jobs_results":
-            self.push_screen(PromptScreen("Job ID for results"), lambda job_id: self._cmd_jobs_results(job_id))
+            self.push_screen(PromptScreen("Job ID for results"), lambda job_id: self._update_details_with_text(jobs_cmds.results(self._runner, job_id or "")) if job_id else None)
         elif result == "jobs_download":
-            self.push_screen(PromptScreen("Job ID to download/list"), lambda job_id: self._cmd_jobs_download(job_id))
+            self.push_screen(PromptScreen("Job ID to download/list"), lambda job_id: self._update_details_with_text(jobs_cmds.download_list_only(self._runner, job_id or "")) if job_id else None)
         elif result == "jobs_cancel":
-            self.push_screen(PromptScreen("Job ID to cancel"), lambda job_id: self._cmd_jobs_cancel(job_id))
+            self.push_screen(PromptScreen("Job ID to cancel"), lambda job_id: self._update_details_with_text(jobs_cmds.cancel(self._runner, job_id or "")) if job_id else None)
         elif result == "projects_list":
-            self.call_later(self._cmd_projects_list)
+            self.call_later(lambda: self._update_details_with_text(projects_cmds.list_projects(self._runner)))
         elif result == "projects_info":
-            self.push_screen(PromptScreen("Project ID"), lambda pid: self._cmd_projects_info(pid))
+            self.push_screen(PromptScreen("Project ID"), lambda pid: self._update_details_with_text(projects_cmds.info(self._runner, pid or "")) if pid else None)
         elif result == "projects_jobs":
-            self.push_screen(PromptScreen("Project ID"), lambda pid: self._cmd_projects_jobs(pid))
+            self.push_screen(PromptScreen("Project ID"), lambda pid: self._update_details_with_text(projects_cmds.jobs(self._runner, pid or "")) if pid else None)
         elif result == "account_info":
-            self.call_later(self._cmd_account_info)
+            self.call_later(lambda: self._update_details_with_text(account_cmds.info(self._runner)))
         elif result == "account_usage":
             def _after_tool(val_tool: Optional[str]):
-                self.push_screen(PromptScreen("Period (month|30days|all)", placeholder="month"), lambda period: self._cmd_account_usage(val_tool, period or "month"))
+                self.push_screen(PromptScreen("Period (month|30days|all)", placeholder="month"), lambda period: self._update_details_with_text(account_cmds.usage(self._runner, val_tool, period or "month")))
             self.push_screen(PromptScreen("Filter by tool (optional)"), _after_tool)
+        elif result == "auth_status":
+            self.call_later(lambda: self._update_details_with_text(auth_cmds.status(self._runner)))
+        elif result == "auth_whoami":
+            self.call_later(lambda: self._update_details_with_text(auth_cmds.whoami(self._runner)))
+        elif result == "auth_logout":
+            self.call_later(lambda: self._update_details_with_text(auth_cmds.logout(self._runner)))
+        elif result == "auth_link":
+            def _after_wait(wait_val: Optional[str]):
+                wait_flag = (wait_val or "no").lower() in {"yes","y","true"}
+                self.call_later(lambda: self._update_details_with_text(auth_cmds.link(self._runner, wait_flag)))
+            self.push_screen(PromptScreen("Wait for linking completion? (yes/no)", placeholder="no"), _after_wait)
+        elif result == "config_show":
+            self.call_later(lambda: self._update_details_with_text(config_cmds.show(self._runner)))
+        elif result == "config_list":
+            self.call_later(lambda: self._update_details_with_text(config_cmds.list_all(self._runner)))
+        elif result == "config_get":
+            self.push_screen(PromptScreen("Config key (e.g., api_url)"), lambda key: self._update_details_with_text(config_cmds.get(self._runner, key or "")) if key else None)
+        elif result == "config_set":
+            def _after_key(key: Optional[str]):
+                if not key:
+                    return
+                self.push_screen(PromptScreen("Value"), lambda val: self._update_details_with_text(config_cmds.set_val(self._runner, key, val or "")) if val is not None else None)
+            self.push_screen(PromptScreen("Config key to set"), _after_key)
+        elif result == "config_reset":
+            self.call_later(lambda: self._update_details_with_text(config_cmds.reset(self._runner)))
+        elif result == "config_path":
+            self.call_later(lambda: self._update_details_with_text(config_cmds.path(self._runner)))
+        elif result == "config_unset":
+            self.push_screen(PromptScreen("Config key to remove"), lambda key: self._update_details_with_text(config_cmds.unset(self._runner, key or "")) if key else None)
+        elif result == "config_export":
+            def _after_fmt(fmt: Optional[str]):
+                self.push_screen(PromptScreen("Output file path (optional)", placeholder="optional"), lambda out: self._update_details_with_text(config_cmds.export(self._runner, fmt or "json", out)))
+            self.push_screen(PromptScreen("Format (json|yaml)", placeholder="json"), _after_fmt)
+        elif result == "config_import":
+            def _after_path(path: Optional[str]):
+                if not path:
+                    return
+                self.push_screen(PromptScreen("Merge with existing? (yes/no)", placeholder="yes"), lambda m: self._update_details_with_text(config_cmds.import_file(self._runner, path, (m or "yes").lower() in {"yes","y","true"})))
+            self.push_screen(PromptScreen("Config file path (.json/.yaml)"), _after_path)
+        elif result == "data_upload":
+            def _after_file(p: Optional[str]):
+                if not p:
+                    return
+                self.push_screen(PromptScreen("Project ID (optional)", placeholder="optional"), lambda pid: self._update_details_with_text(data_cmds.upload(self._runner, p, pid)))
+            self.push_screen(PromptScreen("File path to upload"), _after_file)
+        elif result == "data_list":
+            def _after_fmt(fmt: Optional[str]):
+                self.push_screen(PromptScreen("Project ID (optional)", placeholder="optional"), lambda pid: self._update_details_with_text(data_cmds.list_files(self._runner, pid, fmt or "table")))
+            self.push_screen(PromptScreen("Format (table|json|yaml)", placeholder="table"), _after_fmt)
+        elif result == "data_download":
+            def _after_id(fid: Optional[str]):
+                if not fid:
+                    return
+                self.push_screen(PromptScreen("Output path"), lambda out: self._update_details_with_text(data_cmds.download(self._runner, fid, out or "")) if out else None)
+            self.push_screen(PromptScreen("File ID"), _after_id)
+        elif result == "data_delete":
+            self.push_screen(PromptScreen("File ID to delete"), lambda fid: self._update_details_with_text(data_cmds.delete(self._runner, fid or "")) if fid else None)
+        elif result == "data_sync":
+            def _after_dir(d: Optional[str]):
+                if not d:
+                    return
+                self.push_screen(PromptScreen("Project ID (optional)", placeholder="optional"), lambda pid: self._update_details_with_text(data_cmds.sync(self._runner, d, pid)))
+            self.push_screen(PromptScreen("Local directory to sync"), _after_dir)
         elif result == "artifacts_list":
             self.call_later(self._cmd_artifacts_list)
         elif result == "artifact_preview":
@@ -482,6 +570,32 @@ class IvyBloomTUI(App):
             self.push_screen(PromptScreen("Tool name to run"), lambda tool: self._cmd_run_tool_start(tool))
         elif result == "workflows_run":
             self.push_screen(PromptScreen("Workflow file path"), lambda path: self._cmd_workflows_run_start(path))
+        elif result == "workflows_validate":
+            self.push_screen(PromptScreen("Workflow file path"), lambda path: self._update_details_with_text(workflows_cmds.validate(self._runner, path or "")) if path else None)
+        elif result == "workflows_create":
+            def _after_out(path: Optional[str]):
+                if not path:
+                    return
+                self.push_screen(PromptScreen("Format (yaml|json)", placeholder="yaml"), lambda fmt: self._update_details_with_text(workflows_cmds.create(self._runner, path, fmt or "yaml")))
+            self.push_screen(PromptScreen("Output file path"), _after_out)
+        elif result == "workflows_list":
+            self.call_later(lambda: self._update_details_with_text(workflows_cmds.list_templates(self._runner)))
+        elif result == "batch_submit":
+            def _after_file(path: Optional[str]):
+                if not path:
+                    return
+                self.push_screen(PromptScreen("Extra args (e.g., --dry-run --project-id X)", placeholder="optional"), lambda extra: self._update_details_with_text(batch_cmds.submit(self._runner, path, extra)))
+            self.push_screen(PromptScreen("Batch job file (.yaml/.json)"), _after_file)
+        elif result == "batch_cancel":
+            self.push_screen(PromptScreen("Job IDs (space/comma separated)"), lambda ids: self._update_details_with_text(batch_cmds.cancel(self._runner, ids or "")) if ids else None)
+        elif result == "batch_results":
+            def _after_ids(ids: Optional[str]):
+                if not ids:
+                    return
+                def _after_fmt(fmt: Optional[str]):
+                    self.push_screen(PromptScreen("Output dir (optional)", placeholder="optional"), lambda out: self._update_details_with_text(batch_cmds.results(self._runner, ids, fmt or "json", out)))
+                self.push_screen(PromptScreen("Format (json|yaml|table)", placeholder="json"), _after_fmt)
+            self.push_screen(PromptScreen("Job IDs (space/comma separated)"), _after_ids)
         elif result == "run_custom":
             # Two-step helper: first enter the full command tail, then optional extra env overrides
             def _after_args(extra: Optional[str]):
@@ -706,29 +820,9 @@ class IvyBloomTUI(App):
         if not job_id:
             return
         try:
-            # Thin wrapper: query artifacts via CLI in list-only JSON mode
-            data = self._run_cli_json(["jobs", "download", job_id, "--list-only", "--format", "json"]) or {}
-            candidate_urls: List[str] = []
-            # Preferred selection: artifacts list with type and URL
-            artifacts = []
-            if isinstance(data, dict):
-                artifacts = data.get("artifacts") or []
-            for art in artifacts:
-                if not isinstance(art, dict):
-                    continue
-                url = art.get("presigned_url") or art.get("url")
-                aType = str(art.get("artifact_type") or art.get("type") or "").lower()
-                if url and (any(t in aType for t in ["pdb", "sdf", "primary", "zip"])):
-                    candidate_urls.append(str(url))
-            # Fallback: scan any string URLs elsewhere
-            if not candidate_urls and isinstance(data, dict):
-                for val in data.values():
-                    if isinstance(val, str) and val.startswith("http"):
-                        candidate_urls.append(val)
-                    elif isinstance(val, list):
-                        candidate_urls.extend([v for v in val if isinstance(v, str) and v.startswith("http")])
-            if candidate_urls:
-                webbrowser.open(candidate_urls[0])
+            url = artifacts_cmds.best_artifact_url(self._runner, job_id)
+            if url:
+                webbrowser.open(url)
                 if self.details_summary:
                     self.details_summary.update("Opening artifact in browser...")
             else:
@@ -900,20 +994,12 @@ class IvyBloomTUI(App):
         if not job_id:
             return
         try:
-            import shlex
-            args = ["jobs", "status", job_id, "--format", "table"]
-            if extra_flags:
-                args += shlex.split(extra_flags)
-            # If follow requested, stream lines into Summary
-            follow = any(flag in args for flag in ["--follow", "-f"]) 
-            if follow and self.details_summary:
-                self.details_summary.update("[dim]Following job... press Ctrl+C in terminal to stop.[/dim]")
-                for line in self._runner.run_cli_stream(args):
-                    self.details_summary.update(line)
-            else:
-                text = self._run_cli_text(args, timeout=600) or ""
+            def on_line(line: str) -> None:
                 if self.details_summary:
-                    self.details_summary.update(text)
+                    self.details_summary.update(line)
+            result = jobs_cmds.status(self._runner, job_id, extra_flags, on_line=on_line)
+            if result is not None and self.details_summary:
+                self.details_summary.update(result)
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Jobs status failed: {e}[/red]")
@@ -1059,6 +1145,8 @@ class IvyBloomTUI(App):
                 if self.details_summary:
                     self.details_summary.update("No projects available.")
                 return
+            # Ensure splash is hidden before showing interactive modal
+            self._hide_splash()
             self.push_screen(ProjectPicker(projects), self._on_project_picked)
         except Exception as e:
             if self.details_summary:
@@ -1076,6 +1164,12 @@ class IvyBloomTUI(App):
                 pass
             return
         self.initial_project_id = project_id
+        try:
+            # Persist chosen project for future sessions
+            if self.initial_project_id:
+                self.config.set("last_project_id", self.initial_project_id)
+        except Exception:
+            pass
         if self.details_summary:
             self.details_summary.update(f"Project set to {self.initial_project_id}. Reloading jobs…")
         # Show splash and load jobs now that we have a project
@@ -1112,6 +1206,13 @@ class IvyBloomTUI(App):
         except Exception:
             pass
 
+    # Expose a direct action for keybinding to pick a project even before readiness
+    def action_pick_project(self) -> None:
+        try:
+            self.call_later(self._cmd_pick_project)
+        except Exception:
+            pass
+
     def _cmd_artifacts_list(self) -> None:
         job = self.selected_job
         if not job:
@@ -1197,18 +1298,7 @@ class IvyBloomTUI(App):
                 self.details_summary.update("Invalid job id")
             return
         try:
-            data = self._run_cli_json(["jobs", "download", job_id, "--list-only", "--format", "json"]) or {}
-            artifacts = data.get("artifacts") if isinstance(data, dict) else []
-            url = None
-            if isinstance(artifacts, list):
-                chosen = next((a for a in artifacts if isinstance(a, dict) and a.get("primary")), None)
-                if not chosen:
-                    for pref in ("pdb", "sdf", "zip", "primary"):
-                        chosen = next((a for a in artifacts if isinstance(a, dict) and pref in str(a.get("artifact_type") or a.get("type") or "").lower()), None)
-                        if chosen:
-                            break
-                if chosen:
-                    url = chosen.get("presigned_url") or chosen.get("url")
+            url = artifacts_cmds.primary_artifact_url(self._runner, job_id)
             if url:
                 webbrowser.open(url)
                 if self.details_summary:
@@ -1232,16 +1322,7 @@ class IvyBloomTUI(App):
                 self.details_structure.update("Invalid job id")
             return
         try:
-            data = self._run_cli_json(["jobs", "download", job_id, "--list-only", "--format", "json"]) or {}
-            arts = data.get('artifacts') if isinstance(data, dict) else []
-            pdb_url = None
-            for art in arts or []:
-                if not isinstance(art, dict):
-                    continue
-                aType = str(art.get('artifact_type') or art.get('type') or '').lower()
-                if aType == 'pdb' and art.get('presigned_url'):
-                    pdb_url = art.get('presigned_url')
-                    break
+            pdb_url = artifacts_cmds.pdb_url_for_job(self._runner, job_id)
             if not pdb_url:
                 if self.details_structure:
                     self.details_structure.update("No PDB artifact found")
@@ -1288,3 +1369,282 @@ class IvyBloomTUI(App):
         art, next_angle = self._structure.render_frame_advance(self._structure_points, self._structure_angle, rows=rows, cols=cols, delta=0.12)
         self._structure_angle = next_angle
         self.details_structure.update(art)
+
+    def _update_details_with_text(self, text: str) -> None:
+        try:
+            if self.details_summary:
+                self.details_summary.update(text or "")
+        finally:
+            self._update_status_bar()
+
+    # ------------------ Additional CLI wrappers for parity ------------------
+    def _cmd_auth_status(self) -> None:
+        try:
+            text = self._run_cli_text(["auth", "status"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Auth status failed: {e}[/red]")
+
+    def _cmd_auth_whoami(self) -> None:
+        try:
+            text = self._run_cli_text(["auth", "whoami"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Auth whoami failed: {e}[/red]")
+
+    def _cmd_auth_logout(self) -> None:
+        try:
+            text = self._run_cli_text(["auth", "logout", "--confirm"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text or "Logged out.")
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Logout failed: {e}[/red]")
+
+    def _cmd_auth_link(self, wait: bool) -> None:
+        try:
+            args = ["auth", "link"]
+            if not wait:
+                args.append("--no-wait")
+            text = self._run_cli_text(args, timeout=600) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Auth link failed: {e}[/red]")
+
+    def _cmd_config_show(self) -> None:
+        try:
+            text = self._run_cli_text(["config", "show"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config show failed: {e}[/red]")
+
+    def _cmd_config_list(self) -> None:
+        try:
+            text = self._run_cli_text(["config", "list"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config list failed: {e}[/red]")
+
+    def _cmd_config_get(self, key: Optional[str]) -> None:
+        if not key:
+            return
+        try:
+            text = self._run_cli_text(["config", "get", key]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config get failed: {e}[/red]")
+
+    def _cmd_config_set(self, key: str, value: Optional[str]) -> None:
+        if not key or value is None:
+            return
+        try:
+            text = self._run_cli_text(["config", "set", key, value]) or ""
+            if self.details_summary:
+                self.details_summary.update(text or "Set.")
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config set failed: {e}[/red]")
+
+    def _cmd_config_reset(self) -> None:
+        try:
+            text = self._run_cli_text(["config", "reset", "--confirm"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text or "Reset.")
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config reset failed: {e}[/red]")
+
+    def _cmd_config_path(self) -> None:
+        try:
+            text = self._run_cli_text(["config", "path"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config path failed: {e}[/red]")
+
+    def _cmd_config_unset(self, key: Optional[str]) -> None:
+        if not key:
+            return
+        try:
+            text = self._run_cli_text(["config", "unset", key]) or ""
+            if self.details_summary:
+                self.details_summary.update(text or "Unset.")
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config unset failed: {e}[/red]")
+
+    def _cmd_config_export(self, fmt: str, output: Optional[str]) -> None:
+        try:
+            args = ["config", "export", "--format", fmt or "json"]
+            if output:
+                args += ["--output", output]
+            text = self._run_cli_text(args) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config export failed: {e}[/red]")
+
+    def _cmd_config_import(self, path: str, merge: bool) -> None:
+        if not path:
+            return
+        try:
+            args = ["config", "import", path]
+            if merge:
+                args.append("--merge")
+            text = self._run_cli_text(args) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Config import failed: {e}[/red]")
+
+    def _cmd_data_upload(self, file_path: str, project_id: Optional[str]) -> None:
+        if not file_path:
+            return
+        try:
+            args = ["data", "upload", file_path]
+            if project_id:
+                args += ["--project-id", project_id]
+            text = self._run_cli_text(args, timeout=1200) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Data upload failed: {e}[/red]")
+
+    def _cmd_data_list(self, project_id: Optional[str], fmt: str) -> None:
+        try:
+            args = ["data", "list", "--format", fmt or "table"]
+            if project_id:
+                args += ["--project-id", project_id]
+            text = self._run_cli_text(args) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Data list failed: {e}[/red]")
+
+    def _cmd_data_download(self, file_id: str, output_path: Optional[str]) -> None:
+        if not file_id or not output_path:
+            return
+        try:
+            text = self._run_cli_text(["data", "download", file_id, output_path], timeout=600) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Data download failed: {e}[/red]")
+
+    def _cmd_data_delete(self, file_id: Optional[str]) -> None:
+        if not file_id:
+            return
+        try:
+            text = self._run_cli_text(["data", "delete", file_id, "--confirm"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text or "Deleted.")
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Data delete failed: {e}[/red]")
+
+    def _cmd_data_sync(self, local_dir: str, project_id: Optional[str]) -> None:
+        if not local_dir:
+            return
+        try:
+            args = ["data", "sync", local_dir]
+            if project_id:
+                args += ["--project-id", project_id]
+            text = self._run_cli_text(args, timeout=3600) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Data sync failed: {e}[/red]")
+
+    def _cmd_batch_submit(self, job_file: str, extra: Optional[str]) -> None:
+        if not job_file:
+            return
+        try:
+            import shlex
+            args = ["batch", "submit", job_file]
+            if extra:
+                args += shlex.split(extra)
+            text = self._run_cli_text(args, timeout=3600) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Batch submit failed: {e}[/red]")
+
+    def _cmd_batch_cancel(self, ids: Optional[str]) -> None:
+        if not ids:
+            return
+        try:
+            # Accept space or comma separated
+            raw = (ids or "").replace(",", " ").split()
+            args = ["batch", "cancel"] + raw + ["--confirm"]
+            text = self._run_cli_text(args, timeout=600) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Batch cancel failed: {e}[/red]")
+
+    def _cmd_batch_results(self, ids: str, fmt: str, output_dir: Optional[str]) -> None:
+        if not ids:
+            return
+        try:
+            raw = (ids or "").replace(",", " ").split()
+            args = ["batch", "results"] + raw + ["--format", fmt or "json"]
+            if output_dir:
+                args += ["--output-dir", output_dir]
+            text = self._run_cli_text(args, timeout=3600) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Batch results failed: {e}[/red]")
+
+    def _cmd_workflows_validate(self, path: Optional[str]) -> None:
+        if not path:
+            return
+        try:
+            text = self._run_cli_text(["workflows", "validate", path], timeout=600) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Workflows validate failed: {e}[/red]")
+
+    def _cmd_workflows_create(self, output_file: str, fmt: str) -> None:
+        if not output_file:
+            return
+        try:
+            text = self._run_cli_text(["workflows", "create", output_file, "--format", fmt or "yaml"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Workflows create failed: {e}[/red]")
+
+    def _cmd_workflows_list(self) -> None:
+        try:
+            text = self._run_cli_text(["workflows", "list"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Workflows list failed: {e}[/red]")
