@@ -10,15 +10,18 @@ from rich.table import Table
 
 from ..utils.colors import EARTH_TONES
 from .cli_runner import CLIRunner
+from .debug_logger import DebugLogger
 
 
 class ArtifactsService:
 	"""Service for listing and previewing artifacts via CLI subprocess + HTTP fetch."""
 
-	def __init__(self, runner: CLIRunner) -> None:
+	def __init__(self, runner: CLIRunner, logger: DebugLogger | None = None) -> None:
 		self.runner = runner
+		self._logger = logger or DebugLogger(False, prefix="ART")
 
 	def list_artifacts_table(self, job_id: str) -> Table:
+		self._logger.debug(f"list_artifacts_table: job_id={job_id}")
 		data = self.runner.run_cli_json(["jobs", "download", job_id, "--list-only", "--format", "json"]) or {}
 		table = Table(title="Artifacts", show_header=True, header_style=f"bold {EARTH_TONES['sage_dark']}")
 		table.add_column("Type", style="green")
@@ -38,6 +41,7 @@ class ArtifactsService:
 		return table
 
 	def choose_artifact(self, job_id: str, selector: Optional[str]) -> Optional[Dict[str, Any]]:
+		self._logger.debug(f"choose_artifact: job_id={job_id} selector={selector}")
 		data = self.runner.run_cli_json(["jobs", "download", job_id, "--list-only", "--format", "json"]) or {}
 		arts = data.get('artifacts') if isinstance(data, dict) else []
 		chosen = None
@@ -66,6 +70,7 @@ class ArtifactsService:
 		return chosen
 
 	def fetch_bytes(self, url: str, timeout: int = 15) -> bytes:
+		self._logger.debug(f"fetch_bytes: GET {url} timeout={timeout}")
 		resp = requests.get(url, timeout=timeout)
 		resp.raise_for_status()
 		return resp.content
