@@ -3,13 +3,15 @@ from __future__ import annotations
 from typing import Any, Dict, List, Optional
 
 from .cli_runner import CLIRunner
+from .debug_logger import DebugLogger
 
 
 class JobsService:
 	"""Service to fetch and normalize job data via the CLI."""
 
-	def __init__(self, runner: CLIRunner) -> None:
+	def __init__(self, runner: CLIRunner, logger: DebugLogger | None = None) -> None:
 		self.runner = runner
+		self._logger = logger or DebugLogger(False, prefix="JOBS")
 
 	def list_jobs(self, project_id: Optional[str], limit: int, offset: int) -> List[Dict[str, Any]]:
 		# Always request deterministic paging and include project filter when present
@@ -20,6 +22,7 @@ class JobsService:
 		]
 		if project_id:
 			args += ["--project-id", str(project_id)]
+		self._logger.debug(f"list_jobs: project_id={project_id} limit={limit} offset={offset}")
 		jobs = self.runner.run_cli_json(args) or []
 		if not isinstance(jobs, list):
 			return []
