@@ -271,12 +271,14 @@ class ProjectPicker(ModalScreen[Optional[str]]):
     def compose(self) -> ComposeResult:
         with Vertical():
             yield Static("Select a Project (Enter to confirm, Esc to cancel)")
-            self._list = ListView()
-            # Populate
+            # Create list items directly in compose to avoid append issues
+            list_items = []
             for p in self._projects:
                 pid = str(p.get('project_id') or p.get('id') or '')
                 name = str(p.get('name') or pid or 'Unnamed')
-                self._list.append(ListItem(Static(f"[b]{name}[/b]  [dim]{pid}[/dim]")))
+                list_items.append(ListItem(Static(f"[b]{name}[/b]  [dim]{pid}[/dim]")))
+            
+            self._list = ListView(*list_items)
             yield self._list
 
     def on_mount(self) -> None:
