@@ -38,7 +38,24 @@ class AuthManager:
             self._store_api_key_file(api_key)
     
     def get_api_key(self, username: str = "default") -> Optional[str]:
-        """Retrieve stored API key"""
+        """Retrieve stored API key from env, secure storage, or file fallback.
+        
+        Order of precedence:
+          1) OS env var IVYBLOOM_API_KEY
+          2) OS env var IVY_API_KEY (legacy)
+          3) Secure storage via keyring
+          4) Local file fallback in config dir
+        """
+        # 1) Environment variable overrides for easy persistence in CI/TUI subprocesses
+        try:
+            import os
+            env_api_key = os.getenv("IVYBLOOM_API_KEY") or os.getenv("IVY_API_KEY")
+            if env_api_key:
+                return env_api_key.strip()
+        except Exception:
+            pass
+        
+        # 2) Secure storage via keyring
         try:
             api_key = keyring.get_password(self.service_name, username)
             if api_key:
@@ -46,7 +63,7 @@ class AuthManager:
         except Exception:
             pass
         
-        # Fallback to file storage
+        # 3) Fallback to file storage
         return self._get_api_key_file()
     
     def remove_api_key(self, username: str = "default") -> None:
@@ -436,24 +453,25 @@ class AuthManager:
     def get_auth_headers(self) -> Dict[str, str]:
         """Get authentication headers for API requests.
         
-        If a JWT auth token is stored, use it. Otherwise use API key.
+        Prefer API key for CLI endpoints. Fall back to JWT, then OAuth access token.
+        This ordering ensures stable auth for both CLI commands and TUI-wrapped calls.
         """
         headers: Dict[str, str] = {}
         
-        # Prefer dedicated stored JWT
+        # 1) Prefer API key for stability across environments
+        api_key = self.get_api_key()
+        if api_key:
+            headers["Authorization"] = f"Bearer {api_key}"
+            return headers
+        # 2) Next, dedicated stored JWT (if present)
         jwt_token = self.get_auth_token()
         if jwt_token:
             headers["Authorization"] = f"Bearer {jwt_token}"
             return headers
-        # Next, prefer OAuth access token if present and valid
+        # 3) Finally, OAuth access token if present and valid
         oauth_tokens = self.get_valid_oauth_tokens()
         if oauth_tokens and oauth_tokens.get("access_token"):
             headers["Authorization"] = f"Bearer {oauth_tokens['access_token']}"
-            return headers
-        # Finally, fallback to API key
-        api_key = self.get_api_key()
-        if api_key:
-            headers["Authorization"] = f"Bearer {api_key}"
         return headers
     
     def prompt_for_api_key(self) -> Optional[str]:
