@@ -16,12 +16,47 @@ from typing import Optional, Dict, Any
 from rich.console import Console
 from rich.panel import Panel
 from rich.text import Text
+from rich.progress import Progress, SpinnerColumn, TextColumn, TimeElapsedColumn
+from rich.live import Live
+from rich.align import Align
 
 from .colors import get_console, print_success, print_error, print_info
 from .config import Config
 
 console = get_console()
 
+def try_system_notification(title: str, message: str) -> None:
+    """Try to show a system notification (optional, fails silently)"""
+    try:
+        import subprocess
+        import platform
+        
+        system = platform.system().lower()
+        
+        if system == "darwin":  # macOS
+            subprocess.run([
+                "osascript", "-e", 
+                f'display notification "{message}" with title "{title}"'
+            ], check=False, capture_output=True)
+        elif system == "linux":
+            # Try notify-send (most Linux distros)
+            subprocess.run([
+                "notify-send", title, message
+            ], check=False, capture_output=True)
+        elif system == "windows":
+            # Try Windows toast notification (Windows 10+)
+            try:
+                from plyer import notification
+                notification.notify(
+                    title=title,
+                    message=message,
+                    timeout=3
+                )
+            except ImportError:
+                pass  # plyer not available
+    except Exception:
+        pass  # Ignore all notification errors
+
 class AuthCallbackHandler(http.server.SimpleHTTPRequestHandler):
     """Handle OAuth callback from browser"""
     
@@ -39,12 +74,24 @@ class AuthCallbackHandler(http.server.SimpleHTTPRequestHandler):
             # Extract authorization code or error
             if 'code' in params:
                 self.auth_server.auth_code = params['code'][0]
+                self.auth_server.callback_received = True
+                self.auth_server.callback_event.set()
                 self.send_success_response()
             elif 'error' in params:
                 self.auth_server.auth_error = params['error'][0]
+                self.auth_server.callback_received = True
+                self.auth_server.callback_event.set()
                 self.send_error_response(params.get('error_description', ['Unknown error'])[0])
             else:
+                self.auth_server.callback_received = True
+                self.auth_server.callback_event.set()
                 self.send_error_response("No authorization code received")
+        elif self.path == '/ping':
+            # Simple health check endpoint
+            self.send_response(200)
+            self.send_header('Content-type', 'application/json')
+            self.end_headers()
+            self.wfile.write(b'{"status": "ok"}')
         else:
             self.send_error_response("Invalid callback path")
     
@@ -68,6 +115,11 @@ class AuthCallbackHandler(http.server.SimpleHTTPRequestHandler):
                     min-height: 100vh; 
                     margin: 0; 
                     background: linear-gradient(135deg, #8B7355, #A0956B, #6B8E23);
+                    animation: fadeIn 0.5s ease-in;
+                }
+                @keyframes fadeIn {
+                    from { opacity: 0; transform: scale(0.9); }
+                    to { opacity: 1; transform: scale(1); }
                 }
                 .container { 
                     background: white; 
@@ -75,12 +127,23 @@ class AuthCallbackHandler(http.server.SimpleHTTPRequestHandler):
                     border-radius: 12px; 
                     box-shadow: 0 4px 20px rgba(0,0,0,0.1);
                     text-align: center; 
-                    max-width: 400px;
+                    max-width: 450px;
+                    animation: slideUp 0.6s ease-out;
+                }
+                @keyframes slideUp {
+                    from { transform: translateY(30px); opacity: 0; }
+                    to { transform: translateY(0); opacity: 1; }
                 }
                 .success-icon { 
                     font-size: 3rem; 
                     color: #6B8E23; 
                     margin-bottom: 1rem; 
+                    animation: bounce 0.6s ease-in-out;
+                }
+                @keyframes bounce {
+                    0%, 20%, 50%, 80%, 100% { transform: translateY(0); }
+                    40% { transform: translateY(-10px); }
+                    60% { transform: translateY(-5px); }
                 }
                 .title { 
                     color: #8B7355; 
@@ -89,13 +152,38 @@ class AuthCallbackHandler(http.server.SimpleHTTPRequestHandler):
                 }
                 .message { 
                     color: #666; 
-                    margin-bottom: 2rem; 
+                    margin-bottom: 1.5rem; 
+                    line-height: 1.5;
                 }
                 .ivy-leaf { 
                     color: #6B8E23; 
                     font-size: 2rem; 
                     margin: 1rem 0; 
                 }
+                .next-steps {
+                    background: #f8f9fa;
+                    padding: 1rem;
+                    border-radius: 8px;
+                    margin: 1rem 0;
+                    border-left: 4px solid #6B8E23;
+                }
+                .next-steps h3 {
+                    margin: 0 0 0.5rem 0;
+                    color: #8B7355;
+                    font-size: 1rem;
+                }
+                .next-steps code {
+                    background: #e9ecef;
+                    padding: 0.2rem 0.4rem;
+                    border-radius: 4px;
+                    font-family: 'Monaco', 'Consolas', monospace;
+                    font-size: 0.85rem;
+                }
+                .countdown {
+                    color: #A0956B;
+                    font-size: 0.85rem;
+                    margin-top: 1rem;
+                }
             </style>
         </head>
         <body>
@@ -103,14 +191,73 @@ class AuthCallbackHandler(http.server.SimpleHTTPRequestHandler):
                 <div class="success-icon">✅</div>
                 <div class="ivy-leaf">🌿</div>
                 <h1 class="title">Authentication Successful!</h1>
-                <p class="message">You have successfully authenticated with ivybloom CLI. You can now close this window and return to your terminal.</p>
-                <p style="color: #A0956B; font-size: 0.9rem;">ivybloom CLI - Computational Biology & Drug Discovery</p>
+                <p class="message">
+                    Great! You've successfully authenticated with ivybloom CLI.<br/>
+                    <strong>Return to your terminal</strong> to continue.
+                </p>
+                
+                <div class="next-steps">
+                    <h3>🚀 What's next?</h3>
+                    <p style="margin: 0.5rem 0; font-size: 0.9rem;">Try these commands in your terminal:</p>
+                    <p style="margin: 0.3rem 0;"><code>ivybloom tools list</code></p>
+                    <p style="margin: 0.3rem 0;"><code>ivybloom projects list</code></p>
+                </div>
+                
+                <p class="countdown" id="countdown">This window will close automatically in <span id="timer">5</span> seconds</p>
+                <p style="color: #A0956B; font-size: 0.85rem; margin-top: 1rem;">
+                    ivybloom CLI - Computational Biology & Drug Discovery
+                </p>
             </div>
             <script>
-                // Auto-close window after 3 seconds
+                let timeLeft = 5;
+                const timerElement = document.getElementById('timer');
+                const countdownElement = document.getElementById('countdown');
+                
+                const countdown = setInterval(() => {
+                    timeLeft--;
+                    timerElement.textContent = timeLeft;
+                    
+                    if (timeLeft <= 0) {
+                        clearInterval(countdown);
+                        countdownElement.textContent = 'Closing window...';
+                        window.close();
+                    }
+                }, 1000);
+                
+                // Also try to notify parent if this is in an iframe
+                if (window.parent && window.parent !== window) {
+                    window.parent.postMessage({
+                        type: 'ivybloom_auth_success',
+                        timestamp: new Date().toISOString()
+                    }, '*');
+                }
+                
+                // Try to send a notification ping back to the CLI (optional, will fail silently if blocked)
+                try {
+                    fetch('/ping', { 
+                        method: 'GET',
+                        mode: 'no-cors'
+                    }).catch(() => {
+                        // Ignore errors - this is just a nice-to-have notification
+                    });
+                } catch (e) {
+                    // Ignore - browser security may block this
+                }
+                
+                // Allow manual close
+                document.addEventListener('keydown', (e) => {
+                    if (e.key === 'Escape' || e.key === 'Enter') {
+                        window.close();
+                    }
+                });
+                
+                // Show visual confirmation that auth succeeded
                 setTimeout(() => {
-                    window.close();
-                }, 3000);
+                    document.querySelector('.success-icon').style.transform = 'scale(1.1)';
+                    setTimeout(() => {
+                        document.querySelector('.success-icon').style.transform = 'scale(1)';
+                    }, 200);
+                }, 500);
             </script>
         </body>
         </html>
@@ -187,6 +334,8 @@ class BrowserAuthServer:
         self.auth_error: Optional[str] = None
         self.server: Optional[socketserver.TCPServer] = None
         self.server_thread: Optional[threading.Thread] = None
+        self.callback_received: bool = False
+        self.callback_event = threading.Event()
     
     def start(self):
         """Start the callback server"""
@@ -206,15 +355,59 @@ class BrowserAuthServer:
             self.server_thread.join(timeout=1)
     
     def wait_for_callback(self, timeout: int = 300) -> tuple[Optional[str], Optional[str]]:
-        """Wait for OAuth callback with timeout"""
-        start_time = time.time()
+        """Wait for OAuth callback with timeout and loading indicator"""
         
-        while time.time() - start_time < timeout:
-            if self.auth_code:
-                return self.auth_code, None
-            elif self.auth_error:
-                return None, self.auth_error
-            time.sleep(0.5)
+        # Create a loading indicator with progress tracking
+        with Progress(
+            SpinnerColumn(),
+            TextColumn("[progress.description]{task.description}"),
+            TimeElapsedColumn(),
+            TextColumn("• Timeout in {task.fields[remaining]:.0f}s"),
+            console=console,
+            transient=True
+        ) as progress:
+            
+            task = progress.add_task(
+                "Waiting for authentication in browser...", 
+                total=timeout,
+                remaining=timeout
+            )
+            
+            start_time = time.time()
+            
+            while time.time() - start_time < timeout:
+                elapsed = time.time() - start_time
+                remaining = timeout - elapsed
+                
+                # Update progress
+                progress.update(task, completed=elapsed, remaining=remaining)
+                
+                # Check if callback received
+                if self.callback_event.wait(timeout=0.1):
+                    if self.auth_code:
+                        progress.update(task, description="✅ Authentication successful!")
+                        # Try to show system notification
+                        try_system_notification(
+                            "ivybloom CLI", 
+                            "🎉 Authentication successful! Return to terminal."
+                        )
+                        time.sleep(0.5)  # Brief pause to show success
+                        return self.auth_code, None
+                    elif self.auth_error:
+                        progress.update(task, description="❌ Authentication failed!")
+                        try_system_notification(
+                            "ivybloom CLI", 
+                            "❌ Authentication failed. Check terminal for details."
+                        )
+                        time.sleep(0.5)  # Brief pause to show error
+                        return None, self.auth_error
+                
+                # Small delay to prevent busy waiting
+                time.sleep(0.1)
+            
+            # Timeout reached
+            progress.update(task, description="⏰ Authentication timeout!")
+            time.sleep(0.5)  # Brief pause to show timeout
         
         return None, "Authentication timeout"
 
@@ -294,9 +487,8 @@ def browser_login(api_url: str, port: int = 8080) -> Dict[str, Any]:
             console.print(f"Please manually visit: {auth_url}")
         
         console.print()
-        print_info("Waiting for authentication in browser...")
         
-        # Wait for callback
+        # Wait for callback with loading indicator
         auth_code, error = auth_server.wait_for_callback()
         
         if error:
@@ -305,10 +497,20 @@ def browser_login(api_url: str, port: int = 8080) -> Dict[str, Any]:
         if not auth_code:
             return {"error": "No authorization code received"}
         
+        # Show callback received message
+        print_success("✅ Callback received! Exchanging authorization code for tokens...")
+        
         # Exchange code for tokens
-        token_data = exchange_code_for_tokens(
-            base_url, auth_code, code_verifier, callback_url
-        )
+        with Progress(
+            SpinnerColumn(),
+            TextColumn("Completing authentication..."),
+            console=console,
+            transient=True
+        ) as progress:
+            progress.add_task("", total=1)
+            token_data = exchange_code_for_tokens(
+                base_url, auth_code, code_verifier, callback_url
+            )
         
         return token_data
         
@@ -412,7 +614,7 @@ def device_flow_login(api_url: str) -> Dict[str, Any]:
         return {"error": f"Device flow failed: {e}"}
 
 def poll_device_flow(api_url: str, device_data: Dict[str, Any]) -> Dict[str, Any]:
-    """Poll device flow until completion"""
+    """Poll device flow until completion with loading indicator"""
     
     import httpx
     
@@ -422,42 +624,79 @@ def poll_device_flow(api_url: str, device_data: Dict[str, Any]) -> Dict[str, Any
     
     start_time = time.time()
     
-    with httpx.Client() as client:
-        while time.time() - start_time < expires_in:
-            try:
-                response = client.post(token_url, data={
-                    'grant_type': 'urn:ietf:params:oauth:grant-type:device_code',
-                    'client_id': 'ivybloom-cli',
-                    'device_code': device_data['device_code']
-                })
+    # Create loading indicator for device flow
+    with Progress(
+        SpinnerColumn(),
+        TextColumn("[progress.description]{task.description}"),
+        TimeElapsedColumn(),
+        TextColumn("• Timeout in {task.fields[remaining]:.0f}s"),
+        console=console,
+        transient=True
+    ) as progress:
+        
+        task = progress.add_task(
+            "Waiting for device authorization...", 
+            total=expires_in,
+            remaining=expires_in
+        )
+        
+        with httpx.Client() as client:
+            while time.time() - start_time < expires_in:
+                elapsed = time.time() - start_time
+                remaining = expires_in - elapsed
+                progress.update(task, completed=elapsed, remaining=remaining)
                 
-                if response.status_code == 200:
-                    tokens = response.json()
-                    return {
-                        "access_token": tokens.get("access_token"),
-                        "refresh_token": tokens.get("refresh_token"),
-                        "expires_in": tokens.get("expires_in"),
-                        "token_type": tokens.get("token_type", "Bearer")
-                    }
-                
-                elif response.status_code == 400:
-                    error_data = response.json()
-                    error = error_data.get("error")
+                try:
+                    response = client.post(token_url, data={
+                        'grant_type': 'urn:ietf:params:oauth:grant-type:device_code',
+                        'client_id': 'ivybloom-cli',
+                        'device_code': device_data['device_code']
+                    })
                     
-                    if error == "authorization_pending":
-                        # Still waiting for user authorization
-                        print(".", end="", flush=True)
-                    elif error == "slow_down":
-                        # Increase polling interval
-                        interval += 5
-                    elif error in ["access_denied", "expired_token"]:
-                        return {"error": error_data.get("error_description", error)}
-                
-                time.sleep(interval)
-                
-            except KeyboardInterrupt:
-                return {"error": "Authentication cancelled"}
-            except Exception as e:
-                return {"error": f"Polling failed: {e}"}
+                    if response.status_code == 200:
+                        progress.update(task, description="✅ Device authorization successful!")
+                        try_system_notification(
+                            "ivybloom CLI", 
+                            "🎉 Device authentication successful!"
+                        )
+                        time.sleep(0.5)  # Brief pause to show success
+                        tokens = response.json()
+                        return {
+                            "access_token": tokens.get("access_token"),
+                            "refresh_token": tokens.get("refresh_token"),
+                            "expires_in": tokens.get("expires_in"),
+                            "token_type": tokens.get("token_type", "Bearer")
+                        }
+                    
+                    elif response.status_code == 400:
+                        error_data = response.json()
+                        error = error_data.get("error")
+                        
+                        if error == "authorization_pending":
+                            # Still waiting for user authorization - continue polling
+                            pass
+                        elif error == "slow_down":
+                            # Increase polling interval
+                            interval += 5
+                            progress.update(task, description="Slowing down polling rate...")
+                        elif error in ["access_denied", "expired_token"]:
+                            progress.update(task, description="❌ Device authorization failed!")
+                            time.sleep(0.5)
+                            return {"error": error_data.get("error_description", error)}
+                    
+                    time.sleep(interval)
+                    
+                except KeyboardInterrupt:
+                    progress.update(task, description="❌ Authentication cancelled!")
+                    time.sleep(0.5)
+                    return {"error": "Authentication cancelled"}
+                except Exception as e:
+                    progress.update(task, description="❌ Polling failed!")
+                    time.sleep(0.5)
+                    return {"error": f"Polling failed: {e}"}
+        
+        # Timeout reached
+        progress.update(task, description="⏰ Device flow timeout!")
+        time.sleep(0.5)
     
     return {"error": "Device flow timeout"}
\ No newline at end of file
